@@ -328,10 +328,12 @@
 #	define _FILE_OFFSET_BITS 64
 #endif
 
-/* Check whether conditions for sighandler are met */
-#if !(defined(HAVE_SIGNAL_H_) && defined(HAVE_SYS_RESOURCE_H_) && \
+/* Check whether conditions for sighandler are met under *nix */
+#ifndef WIN32
+#   if !(defined(HAVE_SIGNAL_H_) && defined(HAVE_SYS_RESOURCE_H_) && \
 			defined(HAVE_SYS_TIME_H_) && defined(HAVE_SYS_UCONTEXT_H_))
-#	define NO_SIGHANDLER
+#	  define NO_SIGHANDLER
+#   endif
 #endif
 
 #endif /* !GMT_CONFIG_H */
